==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/autoresponder/translations/autoresponder_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Only for the first time</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Respond to conferences</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Status invisible</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Status busy</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Status available</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Auto Responder</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Auto answer text</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Choose Status</translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>KADU AUTORESPONDER:</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>I am busy.</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/autoresponder/translations/autoresponder_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Only for the first time</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Respond to conferences</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Status invisible</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Status busy</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Status available</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Auto Responder</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Auto answer text</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Choose Status</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>I am busy.</translation>
    </message>
</context>
<context>
    <name>AutoresponderMessageFilter</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation type="unfinished">KADU AUTORESPONDER:</translation>
    </message>
</context>
</TS>
